@@ -10,16 +10,21 @@ from chalk.parsed.duplicate_input_gql import PositionGQL, RangeGQL
 
 
 def node_to_range(node: ast.AST) -> RangeGQL | None:
-    if node.lineno is None or node.col_offset is None or node.end_lineno is None or node.end_col_offset is None:
+    if (
+        getattr(node, "lineno", None) is None
+        or getattr(node, "col_offset", None) is None
+        or getattr(node, "end_lineno", None) is None
+        or getattr(node, "end_col_offset", None) is None
+    ):
         return None
     return RangeGQL(
         start=PositionGQL(
-            line=node.lineno,
-            character=node.col_offset,
+            line=getattr(node, "lineno"),
+            character=getattr(node, "col_offset"),
         ),
         end=PositionGQL(
-            line=node.end_lineno,
-            character=node.end_col_offset,
+            line=getattr(node, "end_lineno"),
+            character=getattr(node, "end_col_offset"),
         ),
     )
 
@@ -169,7 +174,7 @@ def get_function_arg_annotations(node: ast.FunctionDef | ast.AsyncFunctionDef) -
 class _ChalkFunctionReturnFinder(ast.NodeVisitor):
     def __init__(self):
         super().__init__()
-        self.nodes = []
+        self.nodes: "List[ast.Return]" = []
 
     def visit_Return(self, node: ast.Return) -> None:
         self.nodes.append(node)
@@ -177,7 +182,7 @@ class _ChalkFunctionReturnFinder(ast.NodeVisitor):
 
 
 def get_function_return_statement(node: ast.FunctionDef | ast.AsyncFunctionDef) -> List[ast.AST | None]:
-    returns = []
+    returns: "List[ast.AST | None]" = []
     return_finder = _ChalkFunctionReturnFinder()
     return_finder.visit(node)
     for return_stmt in return_finder.nodes:
@@ -200,7 +205,7 @@ def get_missing_return_annotation(node: ast.FunctionDef | ast.AsyncFunctionDef,
         line_no = node.args.args[-1].end_lineno
         col_offset = node.args.args[-1].end_col_offset + 1
     else:
-        if node.lineno is None or node.col_offset is None:
+        if node.lineno is None or node.col_offset is None:  # pyright: ignore[reportUnnecessaryComparison]
             return None
         line_no = node.lineno
         col_offset = node.col_offset
@@ -341,7 +346,7 @@ def get_feature_range(lines: List[str], exp: Select | Union, name: str) -> Range
             select_string = select_str
             break
         select_str = select.alias_or_name.lower()
-        if name == select_str.split()[-1]:
+        if name.lower() == select_str.split()[-1]:
             select_string = select_str
             break
     if select_string is None:
@@ -380,7 +385,7 @@ def get_full_range(lines: List[str]) -> RangeGQL:
         ),
         end=PositionGQL(
             line=len(lines),
-            character=len(lines[-1]),
+            character=len(lines[-1]) if len(lines) > 0 else 0,
         ),
     )
 
