@@ -7,5 +7,7 @@ CHALK_THEME = Theme(
     {
         "progress.elapsed": Style(color=SERENDIPITOUS_PURPLE),
         "progress.download": Style(color=PASTELY_CYAN),
+        "bar.pulse": Style(color=SERENDIPITOUS_PURPLE),
+        "progress.percentage": Style(color=PASTELY_CYAN),
     }
 )
