@@ -6,7 +6,7 @@ import sys
 from abc import abstractmethod
 from collections.abc import Mapping
 from io import BytesIO
-from typing import TYPE_CHECKING, Any, Dict, Iterable, Literal, Tuple, Union
+from typing import TYPE_CHECKING, Any, Dict, Iterable, List, Literal, Tuple, Union
 
 from typing_extensions import Self, dataclass_transform, get_type_hints
 
@@ -17,11 +17,6 @@ BYTEMODEL_NUM_LEN_BYTES: int = 8
 
 if TYPE_CHECKING:
     from pydantic import BaseModel
-else:
-    try:
-        from pydantic.v1 import BaseModel
-    except ImportError:
-        from pydantic import BaseModel
 
 
 class ByteSerializable:
@@ -92,7 +87,7 @@ class ByteBaseModel(ByteSerializable):
 
     @classmethod
     def produce_pydantic_attrs_bytes(cls, start_idx: int, buffer: BytesIO, model: ByteBaseModel) -> Tuple[int, int]:
-        pydantic_map: Dict[str, BaseModel] = model.get_pydantic_models_map()
+        pydantic_map: "Dict[str, BaseModel]" = model.get_pydantic_models_map()
         pydantic_as_json_map = {k: v.json() for k, v in pydantic_map.items()}
         pydantic_map_as_bytes = json.dumps(pydantic_as_json_map).encode("utf-8")
         cur_idx = start_idx
@@ -181,7 +176,7 @@ class ByteBaseModel(ByteSerializable):
 
     @classmethod
     def get_byte_serializable_classes(cls):
-        byte_serializable_classes_in_order = []
+        byte_serializable_classes_in_order: List[type] = []
         for c in cls.get_field_annotations().values():
             if isinstance(c, str):
                 if hasattr(sys.modules[__name__], c):
@@ -212,7 +207,6 @@ class ByteBaseModel(ByteSerializable):
         for (field_name, field_bytes), cls_for_bytes in zip(
             byte_serializables_bytes_items.items(), cls.get_byte_serializable_classes()
         ):
-
             byte_serializable_attrs[field_name] = cls_for_bytes.deserialize(field_bytes)
 
         final_attrs.update(byte_serializable_attrs)
@@ -292,7 +286,7 @@ class ByteBaseModel(ByteSerializable):
 class ByteDict(ByteBaseModel):
     def __init__(self, *args: Mapping[str, Any], **kwargs: Any):
         for arg in args:
-            if not isinstance(arg, Mapping):
+            if not isinstance(arg, Mapping):  # pyright: ignore[reportUnnecessaryIsInstance]
                 raise ValueError(f"Need all args (non-kwargs) in constructor to be dict-like objects. Got: {type(arg)}")
             for k in arg:
                 self[k] = arg[k]
@@ -301,7 +295,7 @@ class ByteDict(ByteBaseModel):
 
         super().__init__()
 
-    def __setitem__(self, key: str, value: Union[bytes, ByteSerializable]):
+    def __setitem__(self, key: str | bytes, value: Union[bytes, ByteSerializable]):
         if not isinstance(key, str):
             raise ValueError(f"Expected key to be a string, got {type(key)}")
         if not isinstance(value, bytes):
@@ -310,7 +304,7 @@ class ByteDict(ByteBaseModel):
         self.__dict__[key] = value
 
     def __getitem__(self, key: str):
-        if not isinstance(key, str):
+        if not isinstance(key, str):  # pyright: ignore[reportUnnecessaryIsInstance]
             raise ValueError(f"Need for keys to be strings, got {type(key)}")
         return self.__dict__[key]
 
