@@ -159,6 +159,7 @@ class AsyncChalkClient:
         connect_timeout: Optional[float] = None,
         headers: Mapping[str, str] | None = None,
         query_context: Mapping[str, Union[str, int, float, bool, None]] | str | None = None,
+        trace: bool = False,
     ) -> OnlineQueryResult:
         """Compute features values using online resolvers.
         See https://docs.chalk.ai/docs/query-basics for more information.
@@ -234,6 +235,10 @@ class AsyncChalkClient:
             An immutable context that can be accessed from Python resolvers.
             This context wraps a JSON-compatible dictionary or JSON string with type restrictions.
             See https://docs.chalk.ai/api-docs#ChalkContext for more information.
+        trace
+            Force tracing on the query. Requests using `trace=True` will be slower
+            than requests using `trace=False`. Requires datadog tracing to be installed
+            for this to have any effect
 
         Other Parameters
         ----------------
