@@ -117,6 +117,7 @@ from chalk.parsed._proto.utils import datetime_to_proto_timestamp, value_to_prot
 from chalk.utils import df_utils
 from chalk.utils.df_utils import record_batch_to_arrow_ipc
 from chalk.utils.grpc import AuthenticatedChalkClientInterceptor, TokenRefresher, UnauthenticatedChalkClientInterceptor
+from chalk.utils.tracing import add_trace_headers
 
 if TYPE_CHECKING:
     from pyarrow import RecordBatch, Table
@@ -143,6 +144,20 @@ def get_trace_id_from_response(call: grpc.Call) -> Optional[str]:
     return None
 
 
+def _merge_headers(
+    headers: None | Sequence[tuple[str, str | bytes]] | Mapping[str, str | bytes],
+    extra_headers: None | Sequence[tuple[str, str | bytes]] | Mapping[str, str | bytes],
+) -> tuple[tuple[str, str | bytes], ...]:
+    headers = _canonicalize_headers(headers)
+    extra_headers = _canonicalize_headers(extra_headers)
+    all_headers: list[tuple[str, str | bytes]] = []
+    for h in headers:
+        all_headers.append(h)
+    for h in extra_headers:
+        all_headers.append(h)
+    return tuple(all_headers)
+
+
 def _canonicalize_headers(
     headers: None | Sequence[tuple[str, str | bytes]] | Mapping[str, str | bytes],
 ) -> tuple[tuple[str, str | bytes], ...]:
@@ -657,6 +672,7 @@ class ChalkGRPCClient:
         request_timeout: Optional[float] = None,
         headers: Mapping[str, str] | Sequence[tuple[str, str | bytes]] | None = None,
         query_context: Mapping[str, Union[str, int, float, bool, None]] | str | None = None,
+        trace: bool = False,
     ) -> OnlineQueryResponse:
         """Compute features values using online resolvers.
 
@@ -804,6 +820,7 @@ class ChalkGRPCClient:
         request_timeout: Optional[float] = None,
         headers: Mapping[str, str] | Sequence[tuple[str, str | bytes]] | None = None,
         query_context: Mapping[str, Union[str, int, float, bool, None]] | None = None,
+        trace: bool = False,
     ) -> online_query_pb2.OnlineQueryBulkResponse:
         request = self._make_query_bulk_request(
             input={k: [v] for k, v in input.items()},
@@ -824,11 +841,16 @@ class ChalkGRPCClient:
             planner_options=planner_options or {},
             query_context=query_context,
         )
+        if trace:
+            extra_headers: dict[str, str] = {}
+            extra_headers = add_trace_headers(extra_headers)
+            headers = _merge_headers(extra_headers, headers)
+        metadata = _canonicalize_headers(headers)
         return self._stub_refresher.call_query_stub(
             lambda x: x.OnlineQueryBulk(
                 request,
                 timeout=request_timeout,
-                metadata=_canonicalize_headers(headers),
+                metadata=metadata,
             )
         )
 
