@@ -20,7 +20,7 @@ from chalk.features.feature_wrapper import FeatureWrapper, ensure_feature, unwra
 from chalk.features.filter import Filter, TimeDelta, after, before
 from chalk.features.hooks import after_all, before_all
 from chalk.features.primary import Primary, is_primary
-from chalk.features.resolver import Cron, Resolver, ResolverProtocol, offline, online, sink
+from chalk.features.resolver import Cron, Resolver, ResolverProtocol, Sink, make_stream_resolver, offline, online, sink
 from chalk.features.tag import Environments, Tags
 from chalk.features.underscore import Underscore, _, __, underscore
 from chalk.queries.scheduled_query import ScheduledQuery  # import to maintain backwards compatibility
@@ -185,7 +185,7 @@ def version(f: Any) -> int | None:
     raise TypeError(f"Could not determine the version of '{f}' as it is not a Feature.")
 
 
-__all__ = [
+__all__ = (
     "Aggregation",
     "CacheStrategy",
     "Cron",
@@ -199,11 +199,14 @@ __all__ = [
     "FeatureWrapper",
     "Features",
     "Filter",
+    "LatLon",
+    "LatLonRadians",
     "MachineType",
     "MissingValueStrategy",
     "Primary",
     "ResolverProtocol",
     "ScheduledQuery",
+    "Sink",
     "TPrimitive",
     "TPrimitiveArrowScalar",
     "Tags",
@@ -212,8 +215,8 @@ __all__ = [
     "TimeDelta",
     "Underscore",
     "Vector",
-    "LatLon",
-    "LatLonRadians",
+    "_",
+    "__",
     "after",
     "after_all",
     "before",
@@ -230,6 +233,7 @@ __all__ = [
     "is_feature_time",
     "is_features_cls",
     "is_primary",
+    "make_stream_resolver",
     "offline",
     "online",
     "op",
@@ -237,8 +241,6 @@ __all__ = [
     "serialize_dtype",
     "sink",
     "tags",
-    "_",
-    "__",
     "underscore",
     "unwrap_feature",
-]
+)
