@@ -8,12 +8,28 @@ import ipaddress
 import typing
 import uuid
 from datetime import date, datetime, time, timedelta
-from typing import TYPE_CHECKING, Any, Dict, FrozenSet, List, Mapping, Set, Tuple, Type, cast
+from typing import (
+    TYPE_CHECKING,
+    Annotated,
+    Any,
+    Dict,
+    FrozenSet,
+    List,
+    Literal,
+    Mapping,
+    Set,
+    Tuple,
+    Type,
+    TypeGuard,
+    cast,
+    get_args,
+    get_origin,
+    is_typeddict,
+)
 
 import attrs
 import google.protobuf.message
 import pyarrow as pa
-from typing_extensions import Annotated, Literal, TypeGuard, get_args, get_origin, is_typeddict
 
 from chalk.features._encoding.http import HttpResponse, get_http_response_as_pyarrow
 from chalk.features._encoding.primitive import ChalkStructType, TPrimitive
