@@ -4,10 +4,10 @@ import collections.abc
 import datetime
 import enum
 import functools
-from typing import TYPE_CHECKING, Any, List, Mapping, Optional, Protocol, Sequence, TypeVar, Union, cast
+from typing import TYPE_CHECKING, Any, List, Mapping, Optional, Protocol, Sequence, TypeGuard, TypeVar, Union, cast
 
 import pyarrow as pa
-from typing_extensions import Self, TypeGuard
+from typing_extensions import Self
 
 from chalk.features._encoding.converter import pyarrow_to_polars
 from chalk.features.feature_field import Feature
