@@ -4,9 +4,7 @@ import asyncio
 import inspect
 import logging
 import time  # Added for measuring duration
-from typing import Any, Callable, Iterable, Optional, Set, Tuple, Union, overload
-
-from typing_extensions import TypeAlias
+from typing import Any, Callable, Iterable, Optional, Set, Tuple, TypeAlias, Union, overload
 
 from chalk.features.tag import Environments
 from chalk.utils.collections import ensure_tuple
