@@ -848,6 +848,8 @@ def BigQuerySource(
     credentials_base64: Optional[str] = ...,
     credentials_path: Optional[str] = ...,
     engine_args: Optional[Dict[str, Any]] = ...,
+    temp_project: Optional[str] = ...,
+    temp_dataset: Optional[str] = ...,
 ) -> BaseSQLSourceProtocol:
     """You can also configure the integration directly using environment
     variables on your local machine or from those added through the
@@ -869,6 +871,10 @@ def BigQuerySource(
         The path to the credentials file to use to connect.
     engine_args
         Additional arguments to use when constructing the SQLAlchemy engine.
+    temp_project
+        The BigQuery project to use for temporary tables.
+    temp_dataset
+        The BigQuery dataset to use for temporary tables.
 
     Returns
     -------
@@ -897,6 +903,8 @@ def BigQuerySource(
     credentials_base64: Optional[str] = None,
     credentials_path: Optional[str] = None,
     engine_args: Optional[Dict[str, Any]] = None,
+    temp_project: Optional[str] = None,
+    temp_dataset: Optional[str] = None,
 ) -> BaseSQLSourceProtocol:
     """Create a BigQuery data source. SQL-based data sources
     created without arguments assume a configuration in your
@@ -914,6 +922,8 @@ def BigQuerySource(
         location=location,
         credentials_base64=credentials_base64,
         credentials_path=credentials_path,
+        temp_project=temp_project,
+        temp_dataset=temp_dataset,
         engine_args=engine_args,
     )
 
