@@ -19,15 +19,16 @@ from typing import (
     Literal,
     Mapping,
     Optional,
+    ParamSpec,
     Sequence,
     Type,
+    TypeAlias,
     TypeVar,
     Union,
     cast,
 )
 
 import yaml
-from typing_extensions import ParamSpec, TypeAlias
 from yaml.scanner import ScannerError
 
 from chalk import Environments, OfflineResolver, OnlineResolver, Tags
