@@ -1,7 +1,5 @@
 import inspect
-from typing import TYPE_CHECKING, Any, Callable, Dict, Literal, Optional, TypeVar, Union
-
-from typing_extensions import ParamSpec
+from typing import TYPE_CHECKING, Any, Callable, Dict, Literal, Optional, ParamSpec, TypeVar, Union
 
 from chalk._lsp.error_builder import get_resolver_error_builder
 from chalk.features.tag import Environments
