@@ -645,6 +645,13 @@ def arrow_ipc_to_record_batch(b: bytes) -> pa.RecordBatch:
     return pa_table_to_recordbatch(t)
 
 
+def arrow_ipc_stream_to_record_batch(b: bytes) -> pa.RecordBatch:
+    bio = io.BytesIO(b)
+    reader = pa_ipc.RecordBatchStreamReader(bio)
+    t: pa.Table = reader.read_all()
+    return pa_table_to_recordbatch(t)
+
+
 def pa_table_to_recordbatch(t: pa.Table) -> pa.RecordBatch:
     return pa.record_batch([c.combine_chunks() for c in t.columns], t.column_names)
 
