@@ -1,13 +1,12 @@
 from __future__ import annotations
 
 import itertools
+import zoneinfo
 from datetime import timedelta
-from typing import TYPE_CHECKING, Any, Iterator, TypeVar
+from typing import TYPE_CHECKING, Any, Iterator, TypeGuard, TypeVar
 
 import pyarrow as pa
-import zoneinfo
 from packaging.version import parse
-from typing_extensions import TypeGuard
 
 from chalk.utils.log_with_context import get_logger
 from chalk.utils.missing_dependency import missing_dependency_exception
