@@ -2,12 +2,11 @@ from __future__ import annotations
 
 import json
 from inspect import isclass
-from typing import Any
+from typing import Any, TypeGuard
 
 import pydantic
 from packaging import version
 from pydantic import BaseModel
-from typing_extensions import TypeGuard
 
 try:
     from pydantic.v1 import BaseModel as V1BaseModel
